@@ -6,6 +6,82 @@ from colored import Style,Fore,Back
 import qrcode
 
 class Lookup:
+	def searchSpec(self,short=False):
+		with Session(ENGINE) as session:
+			fields={i.name:{'default':None,"type":str(i.type).lower()} for i in Entry.__table__.columns}
+			fd=FormBuilder(data=fields)
+
+			query=None
+			if fd is not None:
+				filters=[]
+				for i in fd:
+					if fd[i] is not None:
+						ct=len(BooleanAnswers.comparison_operators)
+						htext=[std_colorize(i,num,ct) for num,i in enumerate(BooleanAnswers.comparison_operators)]
+						htext='\n'.join(htext)
+						operators=[i for i in BooleanAnswers.comparison_operators]
+						
+						if fields[i]['type'] in ['varchar','text','string']:
+							filters.append(getattr(Entry,i).icontains(fd[i]))
+						else:
+							print(htext)
+							operator=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"'{i}' operator? ",helpText=htext,data="integer")
+							if operator is None:
+								return
+							elif operator in ['d',]:
+								operator=0
+							operator=operators[operator]
+
+							if operator == '==':
+								filters.append(getattr(Entry,i)==fd[i])
+							elif operator == '>':
+								filters.append(getattr(Entry,i)>fd[i])
+							elif operator == '>=':
+								filters.append(getattr(Entry,i)>=fd[i])
+							elif operator == '<':
+								filters.append(getattr(Entry,i)<fd[i])
+							elif operator == '<=':
+								filters.append(getattr(Entry,i)<=fd[i])
+							elif operator == '!=':
+								filters.append(getattr(Entry,i)!=fd[i])
+
+				ct=len(BooleanAnswers.and_or)
+				htext=[std_colorize(i,num,ct) for num,i in enumerate(BooleanAnswers.and_or)]
+				htext='\n'.join(htext)
+				operators=[i for i in BooleanAnswers.and_or]
+				print(htext)
+				operator=Prompt.__init2__(None,func=FormBuilderMkText,ptext="and | or? ",helpText=htext,data="integer")
+				if operator is None:
+					return
+				elif operator in ['d',]:
+					operator=0
+				operator=operators[operator]
+
+				if operator == 'and':
+					query=session.query(Entry).filter(and_(*filters))
+					query=orderQuery(query,Entry.Timestamp)
+				elif operator == 'or':
+					query=session.query(Entry).filter(or_(*filters))
+					query=orderQuery(query,Entry.Timestamp)
+				else:
+					query=session.query(Entry).filter(or_(*filters))
+					query=orderQuery(query,Entry.Timestamp)
+			else:
+				query=session.query(Entry)
+				query=orderQuery(query,Entry.Timestamp)
+			if query is not None:
+				results=query.all()
+				cta=len(results)
+				if cta < 1:
+					print("No Results")
+					return
+				for num,i in enumerate(results):
+					if short:
+						print(std_colorize(i.seeShort(),num,cta))
+					else:
+						print(std_colorize(i,num,cta))
+				print(f"Total Results: {len(results)}")
+
 	def entrySearchBlank(self,just_code=True,fix=False):
 		print("Looking for Blank Barcode|Code")
 		with Session(ENGINE) as session:
@@ -149,6 +225,16 @@ class Lookup:
 			'cmds':['13.f','sch blank fx','schblnk fx','sch \'\' fx','sch "" fx','sch blnk fx'],
 			'exec':lambda self=self:self.entrySearchBlank(fix=True),
 			'desc':f'{Fore.light_blue}Search For Product by Entry Data where or_(Entry.Code=="") and set Entry.Code=="UNASSIGNED_TO_NEW_ITEM"'
+			},
+		uuid1():{
+			'cmds':['14','sch spec','schspec','spec sch','search specific','ssp','ssp+'],
+			'exec':lambda self=self:self.searchSpec(),
+			'desc':f'{Fore.light_blue}Search For Product by Entry Data using prompted fields'
+			},
+		uuid1():{
+			'cmds':['14.1','sch spec sht','schspecsht','spec sch sht','search specific short','ssps','ssp-'],
+			'exec':lambda self=self:self.searchSpec(short=True),
+			'desc':f'{Fore.light_blue}Search For Product by Entry Data using prompted fields'
 			}
 		}
 		def mehelp(self):
