@@ -239,7 +239,9 @@ class NEUSetter:
                     'LoadCount',
                     'PalletCount',
                     'ShelfCount',
-                    'CaseCount',]
+                    'CaseCount',
+                    ]
+                fields.extend(LOCATION_FIELDS)
                 fct=len(fields)
                 for num,f in enumerate(fields):
                     msg=f'{Fore.light_green}{num}/{Fore.light_yellow}{num+1} of {Fore.light_red}{fct} -> {Fore.turquoise_4}{f}{Style.reset}'
